@@ -80,7 +80,7 @@ class _RepackModelStep(TrainingStep):
                     artifacts. After the endpoint is created, the inference code
                     might use the IAM role, if it needs to access an AWS resource.
             model_data (str): The S3 location of a SageMaker model data
-                    ``.tar.gz`` file (default: None).
+                    ``.tar.gz`` file.
             entry_point (str): Path (absolute or relative) to the local Python
                     source file which should be executed as the entry point to
                     inference. If ``source_dir`` is specified, then ``entry_point``
@@ -309,6 +309,8 @@ class _RegisterModelStep(ConfigurableRetryStep):
         retry_policies: List[RetryPolicy] = None,
         tags=None,
         container_def_list=None,
+        drift_check_baselines=None,
+        customer_metadata_properties=None,
         **kwargs,
     ):
         """Constructor of a register model step.
@@ -345,6 +347,9 @@ class _RegisterModelStep(ConfigurableRetryStep):
             depends_on (List[str] or List[Step]): A list of step names or instances
                 this step depends on
             retry_policies (List[RetryPolicy]): The list of retry policies for the current step
+            drift_check_baselines (DriftCheckBaselines): DriftCheckBaselines object (default: None).
+            customer_metadata_properties (dict[str, str]): A dictionary of key-value paired
+                metadata properties (default: None).
             **kwargs: additional arguments to `create_model`.
         """
         super(_RegisterModelStep, self).__init__(
@@ -359,6 +364,8 @@ class _RegisterModelStep(ConfigurableRetryStep):
         self.model_package_group_name = model_package_group_name
         self.tags = tags
         self.model_metrics = model_metrics
+        self.drift_check_baselines = drift_check_baselines
+        self.customer_metadata_properties = customer_metadata_properties
         self.metadata_properties = metadata_properties
         self.approval_status = approval_status
         self.image_uri = image_uri
@@ -426,11 +433,13 @@ class _RegisterModelStep(ConfigurableRetryStep):
             model_data=self.model_data,
             image_uri=self.image_uri,
             model_metrics=self.model_metrics,
+            drift_check_baselines=self.drift_check_baselines,
             metadata_properties=self.metadata_properties,
             approval_status=self.approval_status,
             description=self.description,
             tags=self.tags,
             container_def_list=self.container_def_list,
+            customer_metadata_properties=self.customer_metadata_properties,
         )
 
         request_dict = get_create_model_package_request(**model_package_args)
